@@ -8,7 +8,7 @@ _XTRACE_NETWORKING_ODL=$(set +o | grep xtrace)
 set +o xtrace
 
 # OpenDaylight directories
-NETWORKING_ODL_DIR=$DEST/networking-odl
+NETWORKING_ODL_DIR=${NETWORKING_ODL_DIR:-$DEST/networking-odl}
 ODL_DIR=$DEST/opendaylight
 
 # Make sure $ODL_DIR exists
@@ -17,14 +17,17 @@ mkdir -p $ODL_DIR
 # Import utility functions
 source $TOP_DIR/functions
 source $NETWORKING_ODL_DIR/devstack/functions
+source $TOP_DIR/lib/neutron-legacy
 
 # Import bridge data
 source $TOP_DIR/lib/neutron_plugins/ovs_base
 
 # Import ODL settings
 source $NETWORKING_ODL_DIR/devstack/settings.odl
-source $NETWORKING_ODL_DIR/devstack/odl-releases/$ODL_RELEASE
-source $NETWORKING_ODL_DIR/devstack/odl-releases/common
+if [ -r $NETWORKING_ODL_DIR/devstack/odl-releases/$ODL_RELEASE ]; then
+    source $NETWORKING_ODL_DIR/devstack/odl-releases/$ODL_RELEASE
+fi
+source $NETWORKING_ODL_DIR/devstack/odl-releases/common $ODL_RELEASE
 
 # Utilities functions for setting up Java
 source $NETWORKING_ODL_DIR/devstack/setup_java.sh
@@ -45,6 +48,7 @@ fi
 # main loop
 if is_service_enabled odl-server; then
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
+        install_networking_odl
         setup_opendaylight_package
         install_opendaylight
         configure_opendaylight
@@ -82,7 +86,7 @@ if is_service_enabled odl-compute; then
 
         # L3 needs to be configured only for netvirt-ovsdb - in netvirt-vpnservice L3 is configured
         # by provider_mappings, and the provider mappings are added to br-int by default
-        if [[ ",$ODL_NETVIRT_KARAF_FEATURE," =~ ",$ODL_NETVIRT_KARAF_FEATURE_OVSDB," ]] && [ "${ODL_L3}" == "True" ]; then
+        if [[ "${ODL_L3}" == "True" ]]; then
             configure_opendaylight_l3
         fi
     elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
