@@ -16,13 +16,11 @@
 import copy
 import threading
 
-from requests import exceptions
-
+from neutron.db import api as neutron_db_api
+from neutron_lib.plugins import directory
 from oslo_config import cfg
 from oslo_log import log as logging
-
-from neutron.db import api as neutron_db_api
-from neutron import manager
+from requests import exceptions
 
 from networking_odl.common import client
 from networking_odl.common import constants as odl_const
@@ -72,7 +70,7 @@ def _enrich_port(plugin_context, ml2_context, object_type, operation, data):
         if ml2_context:
             network = ml2_context._network_context._network
         else:
-            plugin = manager.NeutronManager.get_plugin()
+            plugin = directory.get_plugin()
             network = plugin.get_network(plugin_context,
                                          new_data['network_id'])
         new_data['tenant_id'] = network['tenant_id']
@@ -127,19 +125,19 @@ class OpendaylightJournalThread(object):
     def _json_data(self, row):
         data = copy.deepcopy(row.data)
         filters.filter_for_odl(row.object_type, row.operation, data)
-        url_object = utils.neutronify(row.object_type)
+        url_object = utils.make_url_object(row.object_type)
 
         if row.operation == odl_const.ODL_CREATE:
             method = 'post'
-            urlpath = url_object + 's'
+            urlpath = url_object
             to_send = {row.object_type: data}
         elif row.operation == odl_const.ODL_UPDATE:
             method = 'put'
-            urlpath = url_object + 's/' + row.object_uuid
+            urlpath = url_object + '/' + row.object_uuid
             to_send = {row.object_type: data}
         elif row.operation == odl_const.ODL_DELETE:
             method = 'delete'
-            urlpath = url_object + 's/' + row.object_uuid
+            urlpath = url_object + '/' + row.object_uuid
             to_send = None
 
         return method, urlpath, to_send
