@@ -19,14 +19,13 @@ from oslo_log import log as logging
 
 from neutron.api.rpc.agentnotifiers import l3_rpc_agent_api
 from neutron.api.rpc.handlers import l3_rpc
-from neutron.common import constants as q_const
 from neutron.common import rpc as n_rpc
 from neutron.common import topics
 from neutron.db import extraroute_db
 from neutron.db import l3_agentschedulers_db
 from neutron.db import l3_dvr_db
 from neutron.db import l3_gwmode_db
-from neutron.plugins.common import constants
+from neutron_lib import constants as q_const
 
 from networking_odl.common import client as odl_client
 from networking_odl.common import utils as odl_utils
@@ -47,11 +46,11 @@ FLOATINGIPS = 'floatingips'
 
 
 class OpenDaylightL3RouterPlugin(
-    common_db_mixin.CommonDbMixin,
-    extraroute_db.ExtraRoute_db_mixin,
-    l3_dvr_db.L3_NAT_with_dvr_db_mixin,
-    l3_gwmode_db.L3_NAT_db_mixin,
-    l3_agentschedulers_db.L3AgentSchedulerDbMixin):
+        common_db_mixin.CommonDbMixin,
+        extraroute_db.ExtraRoute_db_mixin,
+        l3_dvr_db.L3_NAT_with_dvr_db_mixin,
+        l3_gwmode_db.L3_NAT_db_mixin,
+        l3_agentschedulers_db.L3AgentSchedulerDbMixin):
 
     """Implementation of the OpenDaylight L3 Router Service Plugin.
 
@@ -77,7 +76,7 @@ class OpenDaylightL3RouterPlugin(
         self.conn.consume_in_threads()
 
     def get_plugin_type(self):
-        return constants.L3_ROUTER_NAT
+        return q_const.L3
 
     def get_plugin_description(self):
         """returns string description of the plugin."""
@@ -122,10 +121,11 @@ class OpenDaylightL3RouterPlugin(
             fip_dict = super(OpenDaylightL3RouterPlugin,
                              self).update_floatingip(context, id, floatingip)
             # Update status based on association
-            if fip_dict.get('port_id') is None:
-                fip_dict['status'] = q_const.FLOATINGIP_STATUS_DOWN
+            if fip_dict['port_id'] is None:
+                status = q_const.FLOATINGIP_STATUS_DOWN
             else:
-                fip_dict['status'] = q_const.FLOATINGIP_STATUS_ACTIVE
+                status = q_const.FLOATINGIP_STATUS_ACTIVE
+            fip_dict['status'] = status
             self.update_floatingip_status(context, id, fip_dict['status'])
 
         url = FLOATINGIPS + "/" + id
@@ -137,44 +137,6 @@ class OpenDaylightL3RouterPlugin(
         url = FLOATINGIPS + "/" + id
         self.client.sendjson('delete', url, None)
 
-    def add_router_interface(self, context, router_id, interface_info):
-        new_router = super(
-            OpenDaylightL3RouterPlugin, self).add_router_interface(
-                context, router_id, interface_info)
-        url = ROUTERS + "/" + router_id + "/add_router_interface"
-        router_dict = self._generate_router_dict(router_id, interface_info,
-                                                 new_router)
-        self.client.sendjson('put', url, router_dict)
-        return new_router
-
-    def remove_router_interface(self, context, router_id, interface_info):
-        new_router = super(
-            OpenDaylightL3RouterPlugin, self).remove_router_interface(
-                context, router_id, interface_info)
-        url = ROUTERS + "/" + router_id + "/remove_router_interface"
-        router_dict = self._generate_router_dict(router_id, interface_info,
-                                                 new_router)
-        self.client.sendjson('put', url, router_dict)
-        return new_router
-
-    def _generate_router_dict(self, router_id, interface_info, new_router):
-        # Get network info for the subnet that is being added to the router.
-        # Check if the interface information is by port-id or subnet-id
-        add_by_port, add_by_sub = self._validate_interface_info(interface_info)
-        if add_by_sub:
-            _port_id = new_router['port_id']
-            _subnet_id = interface_info['subnet_id']
-        elif add_by_port:
-            _port_id = interface_info['port_id']
-            _subnet_id = new_router['subnet_id']
-
-        router_dict = {'subnet_id': _subnet_id,
-                       'port_id': _port_id,
-                       'id': router_id,
-                       'tenant_id': new_router['tenant_id']}
-
-        return router_dict
-
     dvr_deletens_if_no_port_warned = False
 
     def dvr_deletens_if_no_port(self, context, port_id):
