@@ -28,11 +28,11 @@ from neutron.common import utils
 from neutron import context as neutron_context
 from neutron.extensions import allowedaddresspairs as addr_pair
 from neutron.extensions import multiprovidernet as mpnet
-from neutron.extensions import providernet
 from neutron.extensions import securitygroup as sg
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2 import driver_api
 from neutron.plugins.ml2 import driver_context
+from neutron_lib.api.definitions import provider_net as providernet
 from neutron_lib import exceptions as n_exc
 
 from networking_odl._i18n import _LE
@@ -42,6 +42,7 @@ from networking_odl.common import constants as odl_const
 from networking_odl.common import filters
 from networking_odl.common import utils as odl_utils
 from networking_odl.ml2 import port_binding
+from networking_odl.trunk import trunk_driver_v1 as trunk_driver
 
 
 cfg.CONF.import_group('ml2_odl', 'networking_odl.common.config')
@@ -379,8 +380,8 @@ class OpenDaylightDriver(object):
                            'object_id': obj_id})
                 self.out_of_sync = True
 
-    def sync_from_callback(self, context,
-                           operation, res_type, res_id, resource_dict):
+    def sync_from_callback(self, context, operation, res_type,
+                           res_id, resource_dict, **kwrags):
         object_type = odl_utils.neutronify(res_type.plural)
         try:
             if operation == odl_const.ODL_DELETE:
@@ -460,6 +461,7 @@ class OpenDaylightMechanismDriver(driver_api.MechanismDriver):
         self.username = cfg.CONF.ml2_odl.username
         self.password = cfg.CONF.ml2_odl.password
         self.odl_drv = OpenDaylightDriver()
+        self.trunk_driver = trunk_driver.OpenDaylightTrunkDriverV1.create()
 
     # Postcommit hooks are used to trigger synchronization.
 
