@@ -18,9 +18,10 @@ from oslo_log import log as logging
 
 from neutron.db.models import securitygroup
 from neutron.extensions import multiprovidernet as mpnet
-from neutron.extensions import providernet
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2 import driver_api as api
+from neutron_lib.api.definitions import provider_net as providernet
+from neutron_lib.plugins import directory
 
 from networking_odl._i18n import _, _LE
 from networking_odl.common import callback
@@ -32,6 +33,7 @@ from networking_odl.journal import journal
 from networking_odl.journal import maintenance
 from networking_odl.journal import recovery
 from networking_odl.ml2 import port_binding
+from networking_odl.trunk import trunk_driver_v2 as trunk_driver
 
 LOG = logging.getLogger(__name__)
 
@@ -51,6 +53,7 @@ class OpenDaylightMechanismDriver(api.MechanismDriver):
             self.sync_from_callback_postcommit)
         self.journal = journal.OpendaylightJournalThread()
         self.port_binding_controller = port_binding.PortBindingManager.create()
+        self.trunk_driver = trunk_driver.OpenDaylightTrunkDriverV2.create()
         self._start_maintenance_thread()
 
     def _start_maintenance_thread(self):
@@ -177,7 +180,7 @@ class OpenDaylightMechanismDriver(api.MechanismDriver):
                                rule['id'], odl_const.ODL_CREATE, res_rule)
 
     def sync_from_callback_precommit(self, context, operation, res_type,
-                                     res_id, resource_dict):
+                                     res_id, resource_dict, **kwargs):
         object_type = res_type.singular
         if resource_dict is not None:
             resource_dict = resource_dict[object_type]
@@ -197,6 +200,22 @@ class OpenDaylightMechanismDriver(api.MechanismDriver):
             elif object_type == odl_const.ODL_SG_RULE:
                 resource_dict = self._make_security_group_rule_dict(
                     resource_dict)
+        # NOTE(yamahata): bug work around
+        # callback for update of security grouop doesn't pass complete
+        # info. So we have to build it. Once the bug is fixed, remove
+        # this bug work around.
+        # https://launchpad.net/bugs/1546910
+        # https://review.openstack.org/#/c/281693/
+        elif (object_type == odl_const.ODL_SG and
+              operation == odl_const.ODL_UPDATE):
+            # NOTE(yamahata): precommit_update is called before updating
+            # values. so context.session.{new, dirty} doesn't include sg
+            # in question. a dictionary with new values needs to be build.
+            core_plugin = directory.get_plugin()
+            sg = core_plugin._get_security_group(context, res_id)
+            tmp_dict = self._make_security_group_dict(sg)
+            tmp_dict.update(resource_dict)
+            resource_dict = tmp_dict
 
         object_uuid = (resource_dict.get('id')
                        if operation == 'create' else res_id)
@@ -220,9 +239,18 @@ class OpenDaylightMechanismDriver(api.MechanismDriver):
                     _("unsupporetd bulk creation of security group rule"))
         journal.record(context, None, object_type, object_uuid,
                        operation, resource_dict)
+        # NOTE(yamahata): DB auto deletion
+        # Security Group Rule under this Security Group needs to
+        # be deleted. At NeutronDB layer rules are auto deleted with
+        # cascade='all,delete'.
+        if (object_type == odl_const.ODL_SG and
+                operation == odl_const.ODL_DELETE):
+            for rule in kwargs['security_group'].rules:
+                journal.record(context, None, odl_const.ODL_SG_RULE,
+                               rule.id, odl_const.ODL_DELETE, [object_uuid])
 
     def sync_from_callback_postcommit(self, context, operation, res_type,
-                                      res_id, resource_dict):
+                                      res_id, resource_dict, **kwargs):
         self._postcommit(context)
 
     def _postcommit(self, context):
