@@ -14,11 +14,24 @@
 #    under the License.
 import copy
 import datetime
+import mock
 import operator
+import requests
 import testscenarios
 
+from neutron.db import api as neutron_db_api
+from neutron.db.models import securitygroup
+from neutron.extensions import multiprovidernet as mpnet
+from neutron.plugins.common import constants as p_const
+from neutron.plugins.ml2 import plugin
+from neutron.tests.unit.plugins.ml2 import test_plugin
+from neutron.tests.unit import testlib_api
+from neutron_lib.api.definitions import provider_net as providernet
+from neutron_lib.plugins import directory
+from oslo_config import cfg
+from oslo_serialization import jsonutils
+
 from networking_odl.common import callback
-from networking_odl.common import client
 from networking_odl.common import constants as odl_const
 from networking_odl.common import filters
 from networking_odl.common import utils
@@ -27,23 +40,7 @@ from networking_odl.journal import cleanup
 from networking_odl.journal import journal
 from networking_odl.journal import maintenance
 from networking_odl.ml2 import mech_driver_v2
-from networking_odl.tests import base
-from networking_odl.tests.unit import test_base_db
-
-import mock
-from oslo_config import cfg
-from oslo_serialization import jsonutils
-import requests
-
-from neutron.db import api as neutron_db_api
-from neutron.db.models import securitygroup
-from neutron.extensions import multiprovidernet as mpnet
-from neutron.extensions import providernet
-from neutron import manager
-from neutron.plugins.common import constants as p_const
-from neutron.plugins.ml2 import plugin
-from neutron.tests.unit.plugins.ml2 import test_plugin
-from neutron.tests.unit import testlib_api
+from networking_odl.tests.unit import base_v2
 
 
 # Required to generate tests from scenarios. Not compatible with nose.
@@ -56,32 +53,6 @@ SG_FAKE_ID = 'sg_fake_uuid'
 SG_RULE_FAKE_ID = 'sg_rule_fake_uuid'
 
 
-class OpenDaylightConfigBase(test_plugin.Ml2PluginV2TestCase,
-                             test_base_db.ODLBaseDbTestCase):
-    def setUp(self):
-        self.useFixture(base.OpenDaylightRestClientFixture())
-        super(OpenDaylightConfigBase, self).setUp()
-        cfg.CONF.set_override('mechanism_drivers',
-                              ['logger', 'opendaylight_v2'], 'ml2')
-        self.mock_sync_thread = mock.patch.object(
-            journal.OpendaylightJournalThread, 'start_odl_sync_thread').start()
-        self.mock_mt_thread = mock.patch.object(
-            maintenance.MaintenanceThread, 'start').start()
-
-
-class OpenDaylightTestCase(OpenDaylightConfigBase):
-    def setUp(self):
-        super(OpenDaylightTestCase, self).setUp()
-        self.port_create_status = 'DOWN'
-        self.mech = mech_driver_v2.OpenDaylightMechanismDriver()
-        self.mock_sendjson = mock.patch.object(client.OpenDaylightRestClient,
-                                               'sendjson').start()
-        self.mock_sendjson.side_effect = self.check_sendjson
-
-    def check_sendjson(self, method, urlpath, obj):
-        self.assertFalse(urlpath.startswith("http://"))
-
-
 class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
     def setUp(self):
         super(OpenDayLightMechanismConfigTests, self).setUp()
@@ -122,22 +93,22 @@ class OpenDayLightMechanismConfigTests(testlib_api.SqlTestCase):
 
 
 class OpenDaylightMechanismTestBasicGet(test_plugin.TestMl2BasicGet,
-                                        OpenDaylightTestCase):
+                                        base_v2.OpenDaylightTestCase):
     pass
 
 
 class OpenDaylightMechanismTestNetworksV2(test_plugin.TestMl2NetworksV2,
-                                          OpenDaylightTestCase):
+                                          base_v2.OpenDaylightTestCase):
     pass
 
 
 class OpenDaylightMechanismTestSubnetsV2(test_plugin.TestMl2SubnetsV2,
-                                         OpenDaylightTestCase):
+                                         base_v2.OpenDaylightTestCase):
     pass
 
 
 class OpenDaylightMechanismTestPortsV2(test_plugin.TestMl2PortsV2,
-                                       OpenDaylightTestCase):
+                                       base_v2.OpenDaylightTestCase):
     pass
 
 
@@ -177,7 +148,7 @@ class AttributeDict(dict):
         self.__dict__ = self
 
 
-class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
+class OpenDaylightMechanismDriverTestCase(base_v2.OpenDaylightConfigBase):
     def setUp(self):
         super(OpenDaylightMechanismDriverTestCase, self).setUp()
         self.db_session = neutron_db_api.get_session()
@@ -245,7 +216,7 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
                    'mac_address': '12:34:56:78:21:b6'}
         _network = OpenDaylightMechanismDriverTestCase.\
             _get_mock_network_operation_context().current
-        _plugin = manager.NeutronManager.get_plugin()
+        _plugin = directory.get_plugin()
         _plugin.get_security_group = mock.Mock(return_value=SECURITY_GROUP)
         _plugin.get_port = mock.Mock(return_value=current)
         _plugin.get_network = mock.Mock(return_value=_network)
@@ -263,6 +234,7 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
                                       'project_id': 'test-tenant',
                                       'tenant_id': 'test-tenant',
                                       'description': 'test-description',
+                                      'rules': [],
                                       'id': SG_FAKE_ID}}
         return context
 
@@ -324,18 +296,26 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
             context_ = (copy.deepcopy(context)
                         if operation != odl_const.ODL_DELETE else None)
             if (object_type == odl_const.ODL_SG and
-                    operation == odl_const.ODL_CREATE):
+                    operation in [odl_const.ODL_CREATE, odl_const.ODL_DELETE]):
                 # TODO(yamahata): remove this work around once
                 # https://review.openstack.org/#/c/281693/
                 # is merged.
-                sg = securitygroup.SecurityGroup(
-                    id=res_id, name=context_[object_type]['name'],
-                    tenant_id=context_[object_type]['tenant_id'],
-                    description=context_[object_type]['description'])
-                plugin_context_mock.session.add(sg)
-                context_[odl_const.ODL_SG].pop('id', None)
-            self.mech.sync_from_callback_precommit(
-                plugin_context_mock, operation, res_type, res_id, context_)
+                if operation == odl_const.ODL_CREATE:
+                    sg = securitygroup.SecurityGroup(
+                        id=res_id, name=context_[object_type]['name'],
+                        tenant_id=context_[object_type]['tenant_id'],
+                        description=context_[object_type]['description'])
+                    plugin_context_mock.session.add(sg)
+                    context_[odl_const.ODL_SG].pop('id', None)
+                if operation == odl_const.ODL_DELETE:
+                    sg = mock.Mock()
+                    sg.rules = []
+                self.mech.sync_from_callback_precommit(
+                    plugin_context_mock, operation, res_type, res_id, context_,
+                    security_group=sg)
+            else:
+                self.mech.sync_from_callback_precommit(
+                    plugin_context_mock, operation, res_type, res_id, context_)
         else:
             method = getattr(self.mech, '%s_%s_precommit' % (operation,
                                                              object_type))
@@ -375,6 +355,10 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
         else:
             url = '%s/%ss' % (cfg.CONF.ml2_odl.url, url_object_type)
 
+        if (object_type == odl_const.ODL_SG and
+                operation == odl_const.ODL_CREATE):
+            context = copy.deepcopy(context)
+            context[odl_const.ODL_SG].pop('rules')
         if operation in [odl_const.ODL_CREATE, odl_const.ODL_UPDATE]:
             kwargs = {
                 'url': url,
@@ -594,6 +578,34 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
     def test_sg_rule(self):
         self._test_object_type(odl_const.ODL_SG_RULE)
 
+    def test_sg_delete(self):
+        with mock.patch.object(journal, 'record') as record:
+            context = self._get_mock_operation_context(odl_const.ODL_SG)
+            res_id = context[odl_const.ODL_SG]['id']
+            plugin_context_mock = mock.Mock()
+            plugin_context_mock.session = neutron_db_api.get_session()
+            rule = mock.Mock()
+            rule.id = SG_RULE_FAKE_ID
+            rule.security_group_id = SG_FAKE_ID
+            sg = mock.Mock()
+            sg.id = SG_FAKE_ID
+            sg.rules = [rule]
+            kwargs = {'security_group': sg}
+            self.mech.sync_from_callback_precommit(
+                plugin_context_mock, odl_const.ODL_DELETE,
+                callback._RESOURCE_MAPPING[odl_const.ODL_SG],
+                res_id, context, **kwargs)
+            record.assert_has_calls(
+                [mock.call(mock.ANY, None, 'security_group', 'sg_fake_uuid',
+                           'delete',
+                           {'description': 'test-description',
+                            'project_id': 'test-tenant',
+                            'rules': [],
+                            'tenant_id': 'test-tenant',
+                            'id': 'sg_fake_uuid', 'name': 'test_sg'}),
+                 mock.call(mock.ANY, None, 'security_group_rule',
+                           'sg_rule_fake_uuid', 'delete', ['sg_fake_uuid'])])
+
     def test_sync_multiple_updates(self):
         # add 2 updates
         for i in range(2):
@@ -623,7 +635,7 @@ class OpenDaylightMechanismDriverTestCase(OpenDaylightConfigBase):
         self.assertEqual(2, len(rows))
 
 
-class _OpenDaylightDriverVlanTransparencyBase(OpenDaylightTestCase):
+class _OpenDaylightDriverVlanTransparencyBase(base_v2.OpenDaylightTestCase):
     def _driver_context(self, network):
         return mock.MagicMock(current=network)
 
