@@ -17,15 +17,16 @@
 from os import path
 
 import mock
+from oslo_config import cfg
 from oslo_log import log
 from oslo_serialization import jsonutils
 import requests
 
-from neutron.common import constants as n_constants
-from neutron.extensions import portbindings
 from neutron.plugins.common import constants
 from neutron.plugins.ml2 import driver_api
 from neutron.plugins.ml2 import driver_context
+from neutron_lib.api.definitions import portbindings
+from neutron_lib import constants as n_constants
 
 from networking_odl.common import cache
 from networking_odl.ml2 import mech_driver
@@ -58,6 +59,8 @@ class TestNetworkTopologyManager(base.DietTestCase):
 
     def setUp(self):
         super(TestNetworkTopologyManager, self).setUp()
+        cfg.CONF.set_override('port_binding_controller',
+                              'network-topology', 'ml2_odl')
         self.patch(network_topology.LOG, 'isEnabledFor', lambda level: True)
         # patch given configuration
         self.cfg = mocked_cfg = self.patch(network_topology.client, 'cfg')
