@@ -51,7 +51,7 @@ done
 # Default to environment variables to permit the gate_hook to override
 # when sourcing.
 VENV=${VENV:-dsvm-functional}
-DEVSTACK_PATH=${DEVSTACK_PATH:-$1}
+DEVSTACK_PATH=${DEVSTACK_PATH:-$(cd "$1" && pwd)}
 PROJECT_NAME=${PROJECT_NAME:-networking-odl}
 REPO_BASE=${GATE_DEST:-$(cd $(dirname "$0")/../.. && pwd)}
 INSTALL_MYSQL_ONLY=${INSTALL_MYSQL_ONLY:-False}
@@ -79,6 +79,10 @@ function _init {
     # Allow the gate to override values set by stackrc.
     DEST=${GATE_DEST:-$DEST}
     STACK_USER=${GATE_STACK_USER:-$STACK_USER}
+    REQUIREMENTS_DIR=$DEST/requirements
+    if [[ -n "$SCREEN_LOGDIR" ]]; then
+        mkdir -p $SCREEN_LOGDIR
+    fi
 }
 
 
@@ -96,21 +100,6 @@ function _install_base_deps {
 }
 
 
-function _install_rpc_backend {
-    echo_summary "Installing rabbitmq"
-
-    RABBIT_USERID=${RABBIT_USERID:-stackrabbit}
-    RABBIT_HOST=${RABBIT_HOST:-$SERVICE_HOST}
-    RABBIT_PASSWORD=${RABBIT_HOST:-secretrabbit}
-
-    source $DEVSTACK_PATH/lib/rpc_backend
-
-    enable_service rabbit
-    install_rpc_backend
-    restart_rpc_backend
-}
-
-
 # _install_databases [install_pg]
 function _install_databases {
     local install_pg=${1:-True}
@@ -135,6 +124,8 @@ function _install_databases {
     configure_database_mysql
 
     if [[ "$install_pg" == "True" ]]; then
+        # acl package includes setfacl.
+        install_package acl
         enable_service postgresql
         initialize_database_backends
         install_database
@@ -168,10 +159,80 @@ EOF
 }
 
 
+function _install_infra {
+    echo_summary "Installing infra"
+
+    pip_install -U virtualenv
+    source $DEVSTACK_PATH/lib/infra
+    install_infra
+}
+
+
+function _install_opendaylight {
+    echo_summary "Install OpenDaylight"
+
+    # fake up necessary environment for odl to install/configure
+    source $DEVSTACK_PATH/lib/neutron-legacy
+    neutron_plugin_configure_common
+    _create_neutron_conf_dir
+    mkdir -p $NEUTRON_CONF_DIR
+    touch $NEUTRON_CONF
+    mkdir -p /$Q_PLUGIN_CONF_PATH
+    Q_PLUGIN_CONF_FILE=$Q_PLUGIN_CONF_PATH/$Q_PLUGIN_CONF_FILENAME
+    touch /$Q_PLUGIN_CONF_FILE
+
+    NETWORKING_ODL_DIR=${NETWORKING_ODL_DIR:-$REPO_BASE/networking-odl}
+    ODL_V2DRIVER=${ODL_V2DRIVER:-True}
+    # openstack service provider isn't needed, only ODL neutron northbound
+    # is necessary for functional test
+    ODL_NETVIRT_KARAF_FEATURE=odl-neutron-service,odl-restconf-all,odl-aaa-authn,odl-dlux-core,odl-mdsal-apidocs,odl-neutron-logger
+    if [[ "$VENV" =~ "fullstack" ]]; then
+        # TODO: in future switch to new netvirt
+        ODL_NETVIRT_KARAF_FEATURE=odl-neutron-service,odl-restconf-all,odl-aaa-authn,odl-dlux-core,odl-mdsal-apidocs,odl-ovsdb-openstack,odl-neutron-logger
+    fi
+    ODL_BOOT_WAIT_URL=controller/nb/v2/neutron/networks
+    source $NETWORKING_ODL_DIR/devstack/settings.odl
+
+    set +e
+    curl -o /dev/null --fail --silent --head -u \
+         ${ODL_USERNAME}:${ODL_PASSWORD} \
+         http://${ODL_MGR_IP}:${ODL_PORT}/${ODL_BOOT_WAIT_URL}
+    local result=$?
+    set -e
+    if [ $result -eq 0 ]; then
+        echo_summary "OpenDaylight config appears to be complete, skipping"
+        return 0
+    fi
+
+    # start_odl tries to run under screen session. ensure screen is running
+    USE_SCREEN=$(trueorfalse True USE_SCREEN)
+    if [[ "$USE_SCREEN" == "True" ]]; then
+        # Create a new named screen to run processes in
+        if ! (etype -p screen > /dev/null && screen -ls | egrep -q "[0-9]\.$SCREEN_NAME"); then
+            screen -d -m -S $SCREEN_NAME -t shell -s /bin/bash
+            sleep 1
+        fi
+    fi
+
+    enable_service odl-server
+    if [[ "$VENV" =~ "fullstack" ]]; then
+        enable_service odl-compute
+        # They are needed by configure_opendaylight_l3
+        FLOATING_RANGE=172.24.5.0/24
+        PUBLIC_NETWORK_GATEWAY=172.24.5.1
+    fi
+    source $NETWORKING_ODL_DIR/devstack/plugin.sh stack install
+    source $NETWORKING_ODL_DIR/devstack/plugin.sh stack post-config
+}
+
+
 function _install_post_devstack {
     echo_summary "Performing post-devstack installation"
 
     _install_databases
+    # networkign-odl devstack plugin requires infra
+    _install_infra
+    _install_opendaylight
 
     if is_ubuntu; then
         install_package isc-dhcp-client
@@ -181,7 +242,6 @@ function _install_post_devstack {
     else
         exit_distro_not_supported "installing dhclient package"
     fi
-
 }
 
 
@@ -202,7 +262,6 @@ function configure_host_for_func_testing {
         # installing Networking ODL, so their installation is conditional to
         # minimize the work to do on a devstack-configured host.
         _install_base_deps
-        _install_rpc_backend
     fi
     _install_post_devstack
 }
